#!/bin/sh

# USER: unix user used for installing OPTENET Server.
# INSTALL_DIR: OPTENET Server installation directory.
# USER_REP unix user used for installing OPTENET Reporter.
# INSTALL_DIR_REP: OPTENET Reporter installation directory.
# SERVICE OPTENET OPTENET Server binary
# AUTOSTART_SERVER_NAME System service name for OPTENET Server in boot process.
# AUTOSTART_REPORTER_NAME System service name for OPTENET Reporter in boot process.
# ALL_PACKET_NAME tar package name.
# SERVER_PACKET_NAME tar package name containing OPTENET Server (without extension).
# REPORTER_PACKET_NAME tar package name containing OPTENET Reporter (without extension).
# LISTCLUSTERS listclusters binary
# SERVICE_RHE3 OPTENET Optenet Server binary for RHE3, RH AS 4 and RH ES 4.
# LISTCLUSTERS_RHE3 Listcluster binary for RHE3, RH AS 4 and RH ES 4

USER=optenet
INSTALL_DIR=/usr/local/optenet
USER_REP=reporter
INSTALL_DIR_REP=/usr/local/reporter
SERVICE=/bin/optenet_server
AUTOSTART_SERVER_NAME=optenet
AUTOSTART_REPORTER_NAME=reporter
ALL_PACKET_NAME=optenet-5.27.15-2.03.10
SERVER_PACKET_NAME=optenet-5.27.15
REPORTER_PACKET_NAME=optenet_reporter-2.03.10
LISTCLUSTERS=/manager/listclusters/listclusters
SERVICE_RHE3=/bin/optenet_server.rhe3
LISTCLUSTERS_RHE3=/manager/listclusters/listclusters.rhe3
SERVICE_SUSE93=/bin/optenet_server.suse93
LISTCLUSTERS_SUSE93=/manager/listclusters/listclusters.suse93

TAR_PATH=`pwd`
LD_LIBRARY_PATH=$INSTALL_DIR/bin
export LD_LIBRARY_PATH

# Getting operating system language 
# es_ES.UTF-8, en_US.UTF-8,en_GB.UTF-8, fr_FR.utf, it_IT.utf8, pt_PT.utf8,...
_CURRENT_LANG=`echo $LANG`
_CURRENT_LANG_START=`echo $_CURRENT_LANG | cut -c 1-2`
if test "$_CURRENT_LANG_START" = "es"; then
	LANGUAGE=_ESP
	LANGUAGE_TEXT="esp"
elif test "$_CURRENT_LANG_START" = "en"; then
	LANGUAGE=_ENG
	LANGUAGE_TEXT="eng"
elif test "$_CURRENT_LANG_START" = "fr"; then
	LANGUAGE=_FRA
	LANGUAGE_TEXT="fra"
elif test "$_CURRENT_LANG_START" = "it"; then
	LANGUAGE=_ITA
	LANGUAGE_TEXT="ita"
elif test "$_CURRENT_LANG_START" = "pt"; then
	LANGUAGE=_POR
	LANGUAGE_TEXT="por"
else
	LANGUAGE=_ENG
	LANGUAGE_TEXT="eng"
fi

# print_text
# Prints the desired text
print_text()
{
	#root installation
	ERROR_ROOT_INS_ESP=" Debe acceder al sistema como root para ejecutar este script. " 
	ERROR_ROOT_INS_ENG=" You must be root to execute this script. " 
	ERROR_ROOT_INS_FRA=" Vous devez rentrer en tant que root pour excuterce script. " 
	ERROR_ROOT_INS_ITA=" Deve accedere al sistema come root per eseguire questo script. " 
	ERROR_ROOT_INS_POR=" Deve aceder ao sistema como root para executar este script. "
	#
	YES_ANSWER_ESP="si" 
	YES_ANSWER_ENG="yes" 
	YES_ANSWER_FRA="oui" 
	YES_ANSWER_ITA="si" 
	YES_ANSWER_POR="sim"
	NO_ANSWER_ESP="no" 
	NO_ANSWER_ENG="no" 
	NO_ANSWER_FRA="non" 
	NO_ANSWER_ITA="no" 
	NO_ANSWER_POR="no"
	#
	SELECT_LANGUAGE_INS_ESP=" Seleccione el idioma para el proceso de instalacin: "
	SELECT_LANGUAGE_INS_ENG=" Select the installation setup language: "
	SELECT_LANGUAGE_INS_FRA=" Slectionnez la langue pour le traitement de l'installation: "
	SELECT_LANGUAGE_INS_ITA=" Selezioni la lingua di il processo di installazione: "
	SELECT_LANGUAGE_INS_POR=" Seleccione o idioma a fim de o processo de instalao: "
	ESP_LANGUAGE_INS_ESP=" esp - Espaol. "
	ESP_LANGUAGE_INS_ENG=" esp - Spanish. "
	ESP_LANGUAGE_INS_FRA=" esp - Espagnol. "
	ESP_LANGUAGE_INS_ITA=" esp - Spagnolo. "
	ESP_LANGUAGE_INS_POR=" esp - Espanhol. "
	ENG_LANGUAGE_INS_ESP=" eng - Ingls. "
	ENG_LANGUAGE_INS_ENG=" eng - English. "
	ENG_LANGUAGE_INS_FRA=" eng - Anglais. "
	ENG_LANGUAGE_INS_ITA=" eng - Inglese. "
	ENG_LANGUAGE_INS_POR=" eng - Ingls. "
	FRA_LANGUAGE_INS_ESP=" fra - Francs. "
	FRA_LANGUAGE_INS_ENG=" fra - French. "
	FRA_LANGUAGE_INS_FRA=" fra - Franais. "
	FRA_LANGUAGE_INS_ITA=" fra - Francese. "
	FRA_LANGUAGE_INS_POR=" fra - Francs. "
	ITA_LANGUAGE_INS_ESP=" ita - Italiano. "
	ITA_LANGUAGE_INS_ENG=" ita - Italian. "
	ITA_LANGUAGE_INS_FRA=" ita - Italien. "
	ITA_LANGUAGE_INS_ITA=" ita - Italiano. "
	ITA_LANGUAGE_INS_POR=" ita - Italiano. "
	POR_LANGUAGE_INS_ESP=" por - Portugus. "
	POR_LANGUAGE_INS_ENG=" por - Portuguese. "
	POR_LANGUAGE_INS_FRA=" por - Portugais. "
	POR_LANGUAGE_INS_ITA=" por - Portoghese. "
	POR_LANGUAGE_INS_POR=" por - Portugus. "
	SELECT_OPTION4_INS_ESP=" Elija una opcion esp|eng|fra|ita|por: [esp] "
	SELECT_OPTION4_INS_ENG=" Choose an option eng|esp|fra|ita|por: [eng] "
	SELECT_OPTION4_INS_FRA=" Choisissez une option esp|eng|fra|ita|por: [fra] "
	SELECT_OPTION4_INS_ITA=" Scelga un'opzione esp|eng|fra|ita|por: [ita] "
	SELECT_OPTION4_INS_POR=" Seleccione uma opo esp|eng|fra|ita|por: [por] "
	#
	INSTALL_SERVER_SRV_ESP=" Desea instalar OPTENET Server? "
	INSTALL_SERVER_SRV_ENG=" Do you want to install OPTENET Server? "
	INSTALL_SERVER_SRV_FRA=" Souhaitez-vous installer OPTENET Server? "
	INSTALL_SERVER_SRV_ITA=" Desidera installare OPTENET Server "
	INSTALL_SERVER_SRV_POR=" Deseja instalar OPTENET Server "
	SELECT_OPTION1_SRV_ESP=" Elija una opcion si|no: "
	SELECT_OPTION1_SRV_ENG=" Choose an option yes|no: "
	SELECT_OPTION1_SRV_FRA=" Choisissez une option oui|non: "
	SELECT_OPTION1_SRV_ITA=" Scelga un'opzione si|no: "
	SELECT_OPTION1_SRV_POR=" Seleccione uma opo sim|no: "
	SELECT_MODE_SRV_ESP=" Seleccione la modalidad de OPTENET que desea instalar: "
	SELECT_MODE_SRV_ENG=" Select the OPTENET modality you wish to install: "
	SELECT_MODE_SRV_FRA=" Slectionnez la version d'OPTENET que vous souhaitez installer: "
	SELECT_MODE_SRV_ITA=" Selezioni la modaliti OPTENET che desidera installare: "
	SELECT_MODE_SRV_POR=" Seleccione a modalidade do OPTENET que pretende instalar: "
	INSTALL_RPC_SRV_ESP=" RPC - instala una version de SQUID que se comunica con OPTENET via RPC, opcion por defecto. "
	INSTALL_RPC_SRV_ENG=" RPC - installs a SQUID version that communicates with OPTENET via RPC, default option. "
	INSTALL_RPC_SRV_FRA=" RPC - installe une version de SQUID qui communique avec OPTENET via RPC, option par dfaut. "
	INSTALL_RPC_SRV_ITA=" RPC - installa una versione di SQUID che comunica con OPTENET via RPC, opzione predefinita. "
	INSTALL_RPC_SRV_POR=" RPC - instala uma verso do SQUID que se comunica com o OPTENET via RPC, opo por defeito. "
	INSTALL_ICAP_SRV_ESP=" ICAP - instala OPTENET con su servidor ICAP para integrarse con Appliances que soporten este protocolo. "
	INSTALL_ICAP_SRV_ENG=" ICAP - installs OPTENET with its ICAP server to be integrated with Appliances that support this protocol. "
	INSTALL_ICAP_SRV_FRA=" ICAP - installe OPTENET avec un serveur ICAP pour s'intgrer aux serveurs monofonctionnels qui prennent en charge ce protocole. "
	INSTALL_ICAP_SRV_ITA=" ICAP - installa OPTENET con il suo server ICAP per integrarsi con Applicazioni che supportano questo protocollo. "
	INSTALL_ICAP_SRV_POR=" ICAP  instala o OPTENET com o servidor ICAP para integrar-se com Appliances que suportem este protocolo. "
	INSTALL_BM_SRV_ESP=" BM - instala OPTENET para integrarse con Border Manager. "
	INSTALL_BM_SRV_ENG=" BM - installs OPTENET to communicate with Border Manager. "
	INSTALL_BM_SRV_FRA=" BM - installe OPTENET pour s'intgrer avec Border Manager. "
	INSTALL_BM_SRV_ITA=" BM - installa OPTENET per integrarsi con Border Manager. "
	INSTALL_BM_SRV_POR=" BM  instala o OPTENET para integrar-se com o Border Manager. "
	INSTALL_PIX_SRV_ESP=" PIX - instala OPTENET para integrarse con PIX. "
	INSTALL_PIX_SRV_ENG=" PIX - installs OPTENET to communicate with PIX. "
	INSTALL_PIX_SRV_FRA=" PIX - instale OPTENET pour s'intgrer avec PIX. "
	INSTALL_PIX_SRV_ITA=" PIX - installa OPTENET per integrarsi con PIX. "
	INSTALL_PIX_SRV_POR=" PIX  instala o OPTENET para integrar-se com PIX. "
	INSTALL_UFP_SRV_ESP=" UFP - instala OPTENET para integrarse con Firewall One. "
	INSTALL_UFP_SRV_ENG=" UFP - installs OPTENET to communicate with Firewall One. "
	INSTALL_UFP_SRV_FRA=" UFP - instale OPTENET pour s'intgrer avec Firewall One. "
	INSTALL_UFP_SRV_ITA=" UFP - installa OPTENET per integrarsi con Firewall One. "
	INSTALL_UFP_SRV_POR=" UFP - instala o OPTENET para integrar-se com a Firewall One. "
	INSTALL_CSP_SRV_ESP=" CSP - instala OPTENET para integrarse con NetScreen. "
	INSTALL_CSP_SRV_ENG=" CSP - installs OPTENET to communicate with NetScreen. "
	INSTALL_CSP_SRV_FRA=" CSP - instale OPTENET pour s'intgrer avec Netscreen. "
	INSTALL_CSP_SRV_ITA=" CSP - installa OPTENET per integrarsi con Netscreen. "
	INSTALL_CSP_SRV_POR=" CSP - instala o OPTENET para integrar-se com o NetScreen. "
	INSTALL_IPL_SRV_ESP=" IPL - instala OPTENET para integrarse con iPlanet. "
	INSTALL_IPL_SRV_ENG=" IPL - installs OPTENET to communicate with iPlanet. "
	INSTALL_IPL_SRV_FRA=" IPL - instale OPTENET pour s'intgrer avec iPlanet. "
	INSTALL_IPL_SRV_ITA=" IPL - installa OPTENET per integrarsi con iPlanet. "
	INSTALL_IPL_SRV_POR=" IPL - instala o OPTENET para integrar-se com o iPlanet. "
	SELECT_OPTION2_SRV_ESP=" Elija una opcion RPC|ICAP|BM|PIX|UFP|CSP|IPL: [RPC] "
	SELECT_OPTION2_SRV_ENG=" Choose an option RPC|ICAP|BM|PIX|UFP|CSP|IPL: [RPC] "
	SELECT_OPTION2_SRV_FRA=" Choisissez une option RPC|ICAP|BM|PIX|UFP|CSP|IPL: [RPC] "
	SELECT_OPTION2_SRV_ITA=" Scelga un'opzione RPC|ICAP|BM|PIX|UFP|CSP|IPL: [RPC] "
	SELECT_OPTION2_SRV_POR=" Seleccione uma opo RPC|ICAP|BM|PIX|UFP|CSP|IPL: [RPC] "
	SELECT_OPTION3_SRV_ESP=" Elija una opcion RPC|ICAP|BM|PIX|UFP|CSP|IPL para continuar: [RPC] "
	SELECT_OPTION3_SRV_ENG=" Choose an option RPC|ICAP|BM|PIX|UFP|CSP|IPL to continue: [RPC] "
	SELECT_OPTION3_SRV_FRA=" Choisissez une option RPC|ICAP|BM|PIX|UFP|CSP|IPL  pour continuer: [RPC] "
	SELECT_OPTION3_SRV_ITA=" Scelga un'opzione RPC|ICAP|BM|PIX|UFP|CSP|IPL per continuare: [RPC] "
	SELECT_OPTION3_SRV_POR=" Seleccione uma opo RPC|ICAP|BM|PIX|UFP|CSP|IPL para continuar: [RPC] "
	SELECT_LANGUAGE_SRV_ESP=" Seleccione el idioma por defecto para administrar OPTENET Server: "
	SELECT_LANGUAGE_SRV_ENG=" Select the default OPTENET Server administration language: "
	SELECT_LANGUAGE_SRV_FRA=" Slectionnez la langue par dfaut pour administrer OPTENET Server: "
	SELECT_LANGUAGE_SRV_ITA=" Selezioni la lingua predefinita per amministrare OPTENET Server: "
	SELECT_LANGUAGE_SRV_POR=" Seleccione o idioma por defeito para administrar o OPTENET Server: "
	ESP_LANGUAGE_SRV_ESP=" esp - Espaol. "
	ESP_LANGUAGE_SRV_ENG=" esp - Spanish. "
	ESP_LANGUAGE_SRV_FRA=" esp - Espagnol. "
	ESP_LANGUAGE_SRV_ITA=" esp - Spagnolo. "
	ESP_LANGUAGE_SRV_POR=" esp - Espanhol. "
	ENG_LANGUAGE_SRV_ESP=" eng - Ingls. "
	ENG_LANGUAGE_SRV_ENG=" eng - English. "
	ENG_LANGUAGE_SRV_FRA=" eng - Anglais. "
	ENG_LANGUAGE_SRV_ITA=" eng - Inglese. "
	ENG_LANGUAGE_SRV_POR=" eng - Ingls. "
	FRA_LANGUAGE_SRV_ESP=" fra - Francs. "
	FRA_LANGUAGE_SRV_ENG=" fra - French. "
	FRA_LANGUAGE_SRV_FRA=" fra - Franais. "
	FRA_LANGUAGE_SRV_ITA=" fra - Francese. "
	FRA_LANGUAGE_SRV_POR=" fra - Francs. "
	ITA_LANGUAGE_SRV_ESP=" ita - Italiano. "
	ITA_LANGUAGE_SRV_ENG=" ita - Italian. "
	ITA_LANGUAGE_SRV_FRA=" ita - Italien. "
	ITA_LANGUAGE_SRV_ITA=" ita - Italiano. "
	ITA_LANGUAGE_SRV_POR=" ita - Italiano. "
	POR_LANGUAGE_SRV_ESP=" por - Portugus. "
	POR_LANGUAGE_SRV_ENG=" por - Portuguese. "
	POR_LANGUAGE_SRV_FRA=" por - Portugais. "
	POR_LANGUAGE_SRV_ITA=" por - Portoghese. "
	POR_LANGUAGE_SRV_POR=" por - Portugus. "
	SELECT_OPTION4_SRV_ESP=" Elija una opcion esp|eng|fra|ita|por: [esp] "
	SELECT_OPTION4_SRV_ENG=" Choose an option eng|esp|fra|ita|por: [eng] "
	SELECT_OPTION4_SRV_FRA=" Choisissez une option esp|eng|fra|ita|por: [fra] "
	SELECT_OPTION4_SRV_ITA=" Scelga un'opzione esp|eng|fra|ita|por: [ita] "
	SELECT_OPTION4_SRV_POR=" Seleccione uma opo esp|eng|fra|ita|por: [por] "
	INFO_USER_SRV_ESP=" Creando nuevo usuario $USER con directorio raz $INSTALL_DIR "
	INFO_USER_SRV_ENG=" Creating new user $USER with root directory $INSTALL_DIR "
	INFO_USER_SRV_FRA=" Cration d un nouvel utilisateur $USER avec rpertoire racine $INSTALL_DIR "
	INFO_USER_SRV_ITA=" Si sta creando un nuovo utente $USER con la directory radice $INSTALL_DIR "
	INFO_USER_SRV_POR=" A criar um novo utilizador $USER com directoria raiz $INSTALL_DIR "
	INFO_COPYING_SRV_ESP=" Copiando el software a $INSTALL_DIR "
	INFO_COPYING_SRV_ENG=" Copying the software to $INSTALL_DIR "
	INFO_COPYING_SRV_FRA=" Copie le software sur $INSTALL_DIR "
	INFO_COPYING_SRV_ITA=" Si sta copiando il software a $INSTALL_DIR "
	INFO_COPYING_SRV_POR=" A copiar o software para $INSTALL_DIR "
	SELECT_VERSION_SRV_ESP=" Seleccione la versin que quiere instalar: "
	SELECT_VERSION_SRV_ENG=" Please select the version you wish to install: "
	SELECT_VERSION_SRV_FRA=" Veuillez slectionner la version que vous voulez installer: "
	SELECT_VERSION_SRV_ITA=" Selezioni la versione che desidera installare:  "
	SELECT_VERSION_SRV_POR=" Seleccione a verso que quer instalar: "
	INSTALL_DEMO_SRV_ESP=" dem - Demo. "
	INSTALL_DEMO_SRV_ENG=" dem - Demo (time-limited) "
	INSTALL_DEMO_SRV_FRA=" dem - Version d'valuation "
	INSTALL_DEMO_SRV_ITA=" dem - Demo "
	INSTALL_DEMO_SRV_POR=" dem - Demo "
	INSTALL_PAGO_SRV_ESP=" pay - Versin pagada. "
	INSTALL_PAGO_SRV_ENG=" pay - Paid version "
	INSTALL_PAGO_SRV_FRA=" pay - Version dfinitive avec numro de licence "
	INSTALL_PAGO_SRV_ITA=" pay - Versione pagata "
	INSTALL_PAGO_SRV_POR=" pay - Verso paga "
	SELECT_OPTION5_SRV_ESP=" Elija una opcion dem|pay: [dem] "
	SELECT_OPTION5_SRV_ENG=" Choose an option dem|pay: [dem] "
	SELECT_OPTION5_SRV_FRA=" Choisissez une option dem|pay: [dem] "
	SELECT_OPTION5_SRV_ITA=" Scelga un'opzione dem|pay: [dem] "
	SELECT_OPTION5_SRV_POR=" Seleccione uma opo dem|pay: [dem] "
	INFO_CODE1_SRV_ESP=" Por favor, Introduzca el cdigo de identificacin: "
	INFO_CODE1_SRV_ENG=" Please enter the identification code: "
	INFO_CODE1_SRV_FRA=" Veuillez saisir le numro de licence: "
	INFO_CODE1_SRV_ITA=" Si prega di inserire il codice di identificazione: "
	INFO_CODE1_SRV_POR=" Por favor, introduza o cdigo de identificao: "
	INFO_CODE2_SRV_ESP=" Ejemplo: abcd-abcd-abcd-abcd "
	INFO_CODE2_SRV_ENG=" For instance: abcd-abcd-abcd-abcd "
	INFO_CODE2_SRV_FRA=" Par exemple: abcd-abcd-abcd-abcd "
	INFO_CODE2_SRV_ITA=" Per esempio: abcd-abcd-abcd-abcd "
	INFO_CODE2_SRV_POR=" Por exemplo: abcd-abcd-abcd-abcd "
	INFO_CODE3_SRV_ESP=" El nmero de licencia que ha introducido no es vlido. Intntelo de nuevo. "
	INFO_CODE3_SRV_ENG=" Incorrect license code. Try again. "
	INFO_CODE3_SRV_FRA=" Le numro de licence que vous avez introduit est incorrect. Veuillez ressayer. "
	INFO_CODE3_SRV_ITA=" Il numero di licenza introdotto non  valido. Provare ancora. "
	INFO_CODE3_SRV_POR=" O nmero de licena que introduziu no  vlido. Tente novamente. "
	INFO_CODE4_SRV_ESP=" No se ha podido validar nmero de licencia, instalando versin demo. Intnte validarlo posteriormente desde la administracin web en la opcin Licencia. "
	INFO_CODE4_SRV_ENG=" Cannot validate license code, installing demo version. Try again later in the web administration from License menu. "
	INFO_CODE4_SRV_FRA=" Ce n'a pas tre possible de valider le nmero de licence lors l'installation de la version d'essai. Veuillez essayer ultrieurement  le valider de l'administration web dans l'option Licence. "
	INFO_CODE4_SRV_ITA=" Non pu convalidare numero di licenza , installare la versione del demo. Provi ancora pi successivamente nella gestione di fotoricettore dal menu dell'Licenza. "
	INFO_CODE4_SRV_POR=" No pode validar o nmero de licena, instalar a verso do programa demostrativo. Tente outra vez mais tarde na administrao da correia fotorreceptora do menu da Licena. "
	INFO_SCRIPTS_SRV_ESP=" Ajustando los scripts de  OPTENET Server ... "
	INFO_SCRIPTS_SRV_ENG=" Modifying OPTENET Server scripts ... "
	INFO_SCRIPTS_SRV_FRA=" Ajuste les scripts d'OPTENET Server ... "
	INFO_SCRIPTS_SRV_ITA=" Si stanno configurando gli script di OPTENET Server ... "
	INFO_SCRIPTS_SRV_POR=" A ajustar os scripts do  OPTENET Server ... "
	INFO_LANGUAGE_SRV_ESP=" Ajustando el idioma de instalacion ... "
	INFO_LANGUAGE_SRV_ENG=" Setting administration language ... "
	INFO_LANGUAGE_SRV_FRA=" Ajuste la langue par dfaut pour administrer OPTENET Server ... "
	INFO_LANGUAGE_SRV_ITA=" Si sta configurando la lingua di installazione ... "
	INFO_LANGUAGE_SRV_POR=" A ajustar o idioma de instalao ... "
	INFO_PROPIETARIO_SRV_ESP=" Estableciendo $USER como propietaro del software ... "
	INFO_PROPIETARIO_SRV_ENG=" Establishing $USER as the owner of the software ... "
	INFO_PROPIETARIO_SRV_FRA=" Etabli $USER comme propritaire du software ... "
	INFO_PROPIETARIO_SRV_ITA=" Si sta stabilendo $USER come proprietario del software ... "
	INFO_PROPIETARIO_SRV_POR=" A estabelecer o $USER como proprietrio do software ... "
	INFO_PROXYCACHE_SRV_ESP=" Creando la cach para el proxy ... "
	INFO_PROXYCACHE_SRV_ENG=" Creating proxy cache ... "
	INFO_PROXYCACHE_SRV_FRA=" Creation du cache du proxy ... "
	INFO_PROXYCACHE_SRV_ITA=" Si sta creando il cache per il proxy ... "
	INFO_PROXYCACHE_SRV_POR=" A criar a cache para o proxy ... "
	INFO_CRONTAB1_SRV_ESP=" Para finalizar se programa la tarea para el mantenimiento de logs de squid. "
	INFO_CRONTAB1_SRV_ENG=" Tasks for squid logs rotation is programmed. "
	INFO_CRONTAB1_SRV_FRA=" On programme le travail de rotation de logs de squid. "
	INFO_CRONTAB1_SRV_ITA=" In ultimo si programmano il lavoro per la manutenzione dei log e degli squid. "
	INFO_CRONTAB1_SRV_POR=" Para finalizar  programada a tarefa para a manuteno dos logs de squid. "
	INFO_CRONTAB2_SRV_ESP=" La programacion por defecto es diariamente a las 0:00 horas. "
	INFO_CRONTAB2_SRV_ENG=" The default programming is every day at 0:00. "
	INFO_CRONTAB2_SRV_FRA=" La planification par dfaut est quotidienne  0:00 heures. "
	INFO_CRONTAB2_SRV_ITA=" La programmazione predefinita viene effettuata in modo predefinito ogni giorno alle 0:00. "
	INFO_CRONTAB2_SRV_POR=" A programao por defeito  diariamente s 0:00 horas. "
	INFO_AUTOSTART1_SRV_ESP=" Estableciendo autoarranque de OPTENET Server ... "
	INFO_AUTOSTART1_SRV_ENG=" Setting OPTENET Server as service ... "
	INFO_AUTOSTART1_SRV_FRA=" tablissement en cours du dmarrage automatique d'OPTENET Server ... "
	INFO_AUTOSTART1_SRV_ITA=" Si sta stabilendo l'avvio automatico di OPTENET Server ... "
	INFO_AUTOSTART1_SRV_POR=" A estabelecer auto-arranque do OPTENET Server ... "
	INFO_AUTOSTART2_SRV_ESP=" No se ha podido establecer el arranque automatico de optenet server con el sistema, deber hacerlo de forma manual. "
	INFO_AUTOSTART2_SRV_ENG=" Cannot set automatic start with the system boot, please set it manually. "
	INFO_AUTOSTART2_SRV_FRA=" On ne peut pas tablir le dmarrage automatique d'Optenet server avec le systme.  Veuillez le faire manuellement. "
	INFO_AUTOSTART2_SRV_ITA=" Non tato possibile stabilire l'avvio automatico del server con il sistema, dovrssere effettuato manualmente. "
	INFO_AUTOSTART2_SRV_POR=" No foi possvel arrancar automaticamente o optenet server, deve faze-lo manualmente. "
	INFO_END1_SRV_ESP=" OPTENET Server ha sido instalado. Acceda al sistema como \" $USER \" y ejecute "
	INFO_END1_SRV_ENG=" OPTENET Server has been installed. Access the system as \" $USER \" and execute "
	INFO_END1_SRV_FRA=" OPTENET Server a t install. Accdez au systme en tant que \" $USER \" et excutez "
	INFO_END1_SRV_ITA=" OPTENET Server tato installato. Acceda al sistema come \" $USER \" ed esegua "
	INFO_END1_SRV_POR=" OPTENET Server foi instalado. Aceda ao sistema como \" $USER \" e execute "
	INFO_END2_SRV_ESP=" ./filterinit start para iniciarlo. Por favor, lea el archivo OptenetManual.pdf "
	INFO_END2_SRV_ENG=" ./filterinit start to start it. Please read the file OPTENETManual.pdf for more "
	INFO_END2_SRV_FRA=" ./filterinit start pour le dmarrer. Consultez le fichier OptenetManual.pdf "
	INFO_END2_SRV_ITA=" ./filterinit start per iniziarlo. Si prega di leggere il file OptenetManual.pdf "
	INFO_END2_SRV_POR=" ./filterinit start para inici-lo. Por favor, leia o ficheiro OptenetManual.pdf "
	INFO_END3_SRV_ESP=" para ms informacin acerca de la configuracin de OPTENET Server. Puede obtener "
	INFO_END3_SRV_ENG=" information about the configuration of OPTENET Server. You can get "
	INFO_END3_SRV_FRA=" pour de plus amples informations sur la configuration d'OPTENET Server. Vous pouvez obtenir "
	INFO_END3_SRV_ITA=" per ulteriori informazioni sulla configurazione di OPTENET Server. Putenersi "
	INFO_END3_SRV_POR=" para obter mais informao sobre a configurao do OPTENET Server. Pode obter "
	INFO_END4_SRV_ESP=" asistencia tcnica escribiendo a support@optenet.com. "
	INFO_END4_SRV_ENG=" technical assistance by writing to support@optenet.com. "
	INFO_END4_SRV_FRA=" un support technique en crivant  support@optenet.com. "
	INFO_END4_SRV_ITA=" assistenza tecnica scrivendo a support@optenet.com. "
	INFO_END4_SRV_POR=" assistncia tcnica enviando um email a support@optenet.com. "
	#
	INSTALL_REPORTER_RPT_ESP=" Desea instalar OPTENET Reporter? "
	INSTALL_REPORTER_RPT_ENG=" Do you want to install OPTENET Reporter? "
	INSTALL_REPORTER_RPT_FRA=" Souhaitez-vous installer OPTENET Reporter? "
	INSTALL_REPORTER_RPT_ITA=" Desidera installare OPTENET Reporter "
	INSTALL_REPORTER_RPT_POR=" Deseja instalar OPTENET Reporter "
	SELECT_OPTION1_RPT_ESP=" Elija una opcion si|no: "
	SELECT_OPTION1_RPT_ENG=" Choose an option yes|no: "
	SELECT_OPTION1_RPT_FRA=" Choisissez une option oui|non: "
	SELECT_OPTION1_RPT_ITA=" Scelga un'opzione si|no: "
	SELECT_OPTION1_RPT_POR=" Seleccione uma opo sim|no: "
	SELECT_LANGUAGE_RPT_ESP=" Seleccione el idioma por defecto para administrar OPTENET Reporter: "
	SELECT_LANGUAGE_RPT_ENG=" Select the default OPTENET Reporter administration language: "
	SELECT_LANGUAGE_RPT_FRA=" Slectionnez la langue par dfaut pour administrer OPTENET Reporter: "
	SELECT_LANGUAGE_RPT_ITA=" Selezioni la lingua predefinita per amministrare OPTENET Reporter: "
	SELECT_LANGUAGE_RPT_POR=" Seleccione o idioma por defeito para administrar o OPTENET Reporter: "
	ESP_LANGUAGE_RPT_ESP=" esp - Espaol. "
	ESP_LANGUAGE_RPT_ENG=" esp - Spanish. "
	ESP_LANGUAGE_RPT_FRA=" esp - Espagnol. "
	ESP_LANGUAGE_RPT_ITA=" esp - Spagnolo. "
	ESP_LANGUAGE_RPT_POR=" esp - Espanhol. "
	ENG_LANGUAGE_RPT_ESP=" eng - Ingls. "
	ENG_LANGUAGE_RPT_ENG=" eng - English. "
	ENG_LANGUAGE_RPT_FRA=" eng - Anglais. "
	ENG_LANGUAGE_RPT_ITA=" eng - Inglese. "
	ENG_LANGUAGE_RPT_POR=" eng - Ingls. "
	FRA_LANGUAGE_RPT_ESP=" fra - Francs. "
	FRA_LANGUAGE_RPT_ENG=" fra - French. "
	FRA_LANGUAGE_RPT_FRA=" fra - Franais. "
	FRA_LANGUAGE_RPT_ITA=" fra - Francese. "
	FRA_LANGUAGE_RPT_POR=" fra - Francs. "
	ITA_LANGUAGE_RPT_ESP=" ita - Italiano. "
	ITA_LANGUAGE_RPT_ENG=" ita - Italian. "
	ITA_LANGUAGE_RPT_FRA=" ita - Italien. "
	ITA_LANGUAGE_RPT_ITA=" ita - Italiano. "
	ITA_LANGUAGE_RPT_POR=" ita - Italiano. "
	POR_LANGUAGE_RPT_ESP=" por - Portugus. "
	POR_LANGUAGE_RPT_ENG=" por - Portuguese. "
	POR_LANGUAGE_RPT_FRA=" por - Portugais. "
	POR_LANGUAGE_RPT_ITA=" por - Portoghese. "
	POR_LANGUAGE_RPT_POR=" por - Portugus. "
	SELECT_OPTION4_RPT_ESP=" Elija una opcion esp|eng|fra|ita|por: [esp] "
	SELECT_OPTION4_RPT_ENG=" Choose an option eng|esp|fra|ita|por: [eng] "
	SELECT_OPTION4_RPT_FRA=" Choisissez une option esp|eng|fra|ita|por: [fra] "
	SELECT_OPTION4_RPT_ITA=" Scelga un'opzione esp|eng|fra|ita|por: [ita] "
	SELECT_OPTION4_RPT_POR=" Seleccione uma opo esp|eng|fra|ita|por: [por] "
	INFO_USER_RPT_ESP=" Creando nuevo usuario $USER_REP con directorio raz $INSTALL_DIR_REP "
	INFO_USER_RPT_ENG=" Creating new user $USER_REP with root directory $INSTALL_DIR_REP "
	INFO_USER_RPT_FRA=" Cration d un nouvel utilisateur $USER_REP avec rpertoire racine $INSTALL_DIR_REP "
	INFO_USER_RPT_ITA=" Si sta creando un nuovo utente $USER_REP con la directory radice $INSTALL_DIR_REP "
	INFO_USER_RPT_POR=" A criar um novo utilizador $USER_REP com directoria raiz $INSTALL_DIR_REP "
	INFO_COPYING_RPT_ESP=" Copiando el software a $INSTALL_DIR_REP "
	INFO_COPYING_RPT_ENG=" Copying the software to $INSTALL_DIR_REP "
	INFO_COPYING_RPT_FRA=" Copie le software sur $INSTALL_DIR_REP "
	INFO_COPYING_RPT_ITA=" Si sta copiando il software a $INSTALL_DIR_REP "
	INFO_COPYING_RPT_POR=" A copiar o software para $INSTALL_DIR_REP "
	INFO_SCRIPTS_RPT_ESP=" Ajustando los scripts de  OPTENET Reporter "
	INFO_SCRIPTS_RPT_ENG=" Modifying OPTENET Reporter scripts "
	INFO_SCRIPTS_RPT_FRA=" Ajuste les scripts d'OPTENET Reporter "
	INFO_SCRIPTS_RPT_ITA=" Si stanno configurando gli script di OPTENET Reporter "
	INFO_SCRIPTS_RPT_POR=" A ajustar os scripts do  OPTENET Reporter "
	INFO_LANGUAGE_RPT_ESP=" Ajustando el idioma de instalacion "
	INFO_LANGUAGE_RPT_ENG=" Setting administration language "
	INFO_LANGUAGE_RPT_FRA=" Ajuste la langue par dfaut pour administrer OPTENET Reporter "
	INFO_LANGUAGE_RPT_ITA=" Si sta configurando la lingua di installazione "
	INFO_LANGUAGE_RPT_POR=" A ajustar o idioma de instalao "
	INFO_FILTERS_RPT_ESP=" Ajustando los filtros gestionados por defecto "
	INFO_FILTERS_RPT_ENG=" Setting default filter "
	INFO_FILTERS_RPT_FRA=" Ajuster les filtres gestionns par dfaut "
	INFO_FILTERS_RPT_ITA=" Si stanno configurando i filtri gestiti in modo predefinito "
	INFO_FILTERS_RPT_POR=" A ajustar os filtros geridos por defeito "
	INFO_PROPIETARIO_RPT_ESP=" Estableciendo $USER_REP como propietaro del software "
	INFO_PROPIETARIO_RPT_ENG=" Establishing $USER_REP as the owner of the software "
	INFO_PROPIETARIO_RPT_FRA=" Etabli $USER_REP comme propritaire du software "
	INFO_PROPIETARIO_RPT_ITA=" Si sta stabilendo $USER_REP come proprietario del software "
	INFO_PROPIETARIO_RPT_POR=" A estabelecer o $USER_REP como proprietrio do software "
	INFO_AUTOSTART1_RPT_ESP=" Estableciendo autoarranque de OPTENET Reporter "
	INFO_AUTOSTART1_RPT_ENG=" Setting OPTENET Reporter as service "
	INFO_AUTOSTART1_RPT_FRA=" tablissement en cours du dmarrage automatique d'OPTENET Reporter "
	INFO_AUTOSTART1_RPT_ITA=" Si sta stabilendo l'avvio automatico di OPTENET Reporter "
	INFO_AUTOSTART1_RPT_POR=" A estabelecer auto-arranque do OPTENET Reporter "
	INFO_AUTOSTART2_RPT_ESP=" No se ha podido establecer el arranque automatico de optenet reporter con el sistema, deber hacerlo de forma manual. "
	INFO_AUTOSTART2_RPT_ENG=" Cannot set automatic start with the system boot, please set it manually. "
	INFO_AUTOSTART2_RPT_FRA=" On ne peut pas tablir le dmarrage automatique d'Optenet avec le systme.  Veuillez le faire manuellement. "
	INFO_AUTOSTART2_RPT_ITA=" Non tato possibile stabilire l'avvio automatico del reporter con il sistema, dovrssere effettuato manualmente. "
	INFO_AUTOSTART2_RPT_POR=" No foi possvel arrancar automaticamente o optenet reporter, deve faze-lo manualmente. "
	INFO_END1_RPT_ESP=" OPTENET Reporter ha sido instalado. Acceda al sistema como \" $USER_REP \" y ejecute "
	INFO_END1_RPT_ENG=" OPTENET Reporter has been installed. Access the system as \" $USER_REP \" and execute "
	INFO_END1_RPT_FRA=" OPTENET Reporter a t install. Accdez au systme en tant que \" $USER_REP \" et excutez "
	INFO_END1_RPT_ITA=" OPTENET Reporter tato installato. Acceda al sistema come \" $USER_REP \" ed esegua "
	INFO_END1_RPT_POR=" OPTENET Reporter foi instalado. Aceda ao sistema como \" $USER_REP \" e execute "
	INFO_END2_RPT_ESP=" ./reporterinit start para iniciarlo. Por favor, lea el archivo OptenetReporterManual.pdf "
	INFO_END2_RPT_ENG=" ./reporterinit start to start it. Please read the file OptenetReporterManual.pdf for more "
	INFO_END2_RPT_FRA=" ./reporterinit start pour le dmarrer. Consultez le fichier OptenetReporterManual.pdf "
	INFO_END2_RPT_ITA=" ./reporterinit start per iniziarlo. Si prega di leggere il file OptenetReporterManual.pdf "
	INFO_END2_RPT_POR=" ./reporterinit start para inici-lo. Por favor, leia o ficheiro OptenetReporterManual.pdf "
	INFO_END3_RPT_ESP=" para ms informacin acerca de la configuracin de OPTENET Reporter. Puede obtener "
	INFO_END3_RPT_ENG=" information about the configuration of OPTENET Reporter. You can get "
	INFO_END3_RPT_FRA=" pour de plus amples informations sur la configuration d'OPTENET Reporter. Vous pouvez obtenir "
	INFO_END3_RPT_ITA=" per ulteriori informazioni sulla configurazione di OPTENET Reporter. Putenersi "
	INFO_END3_RPT_POR=" para obter mais informao sobre a configurao do OPTENET Reporter. Pode obter "
	INFO_END4_RPT_ESP=" asistencia tcnica escribiendo a support@optenet.com. "
	INFO_END4_RPT_ENG=" technical assistance by writing to support@optenet.com. "
	INFO_END4_RPT_FRA=" un support technique en crivant  support@optenet.com. "
	INFO_END4_RPT_ITA=" assistenza tecnica scrivendo a support@optenet.com. "
	INFO_END4_RPT_POR=" assistncia tcnica enviando um email a support@optenet.com. "
	case $1 in
		#to install you must be root
		"error root ins") eval echo "\$ERROR_ROOT_INS"$LANGUAGE;;
		#choose installation process language
		"select language ins") eval echo "\$SELECT_LANGUAGE_INS"$LANGUAGE;;
		"esp language ins") eval echo "\$ESP_LANGUAGE_INS"$LANGUAGE;;
		"eng language ins") eval echo "\$ENG_LANGUAGE_INS"$LANGUAGE;;
		"fra language ins") eval echo "\$FRA_LANGUAGE_INS"$LANGUAGE;;
		"ita language ins") eval echo "\$ITA_LANGUAGE_INS"$LANGUAGE;;
		"por language ins") eval echo "\$POR_LANGUAGE_INS"$LANGUAGE;;
		"select option4 ins") eval echo "\$SELECT_OPTION4_INS"$LANGUAGE;;
		#optenet server
		"install server srv") eval echo "\$INSTALL_SERVER_SRV"$LANGUAGE;;
		"select option1 srv") eval echo "\$SELECT_OPTION1_SRV"$LANGUAGE ["\$YES_ANSWER"$LANGUAGE];;
		"select mode srv") eval echo "\$SELECT_MODE_SRV"$LANGUAGE;;
		"install rpc srv") eval echo "\$INSTALL_RPC_SRV"$LANGUAGE;;
		"install icap srv") eval echo "\$INSTALL_ICAP_SRV"$LANGUAGE;;
		"install bm srv") eval echo "\$INSTALL_BM_SRV"$LANGUAGE;;
		"install pix srv") eval echo "\$INSTALL_PIX_SRV"$LANGUAGE;;
		"install ufp srv") eval echo "\$INSTALL_UFP_SRV"$LANGUAGE;;
		"install csp srv") eval echo "\$INSTALL_CSP_SRV"$LANGUAGE;;
		"install ipl srv") eval echo "\$INSTALL_IPL_SRV"$LANGUAGE;;
		"select option2 srv") eval echo "\$SELECT_OPTION2_SRV"$LANGUAGE;;
		"select option3 srv") eval echo "\$SELECT_OPTION3_SRV"$LANGUAGE;;
		"select language srv") eval echo "\$SELECT_LANGUAGE_SRV"$LANGUAGE;;
		"esp language srv") eval echo "\$ESP_LANGUAGE_SRV"$LANGUAGE;;
		"eng language srv") eval echo "\$ENG_LANGUAGE_SRV"$LANGUAGE;;
		"fra language srv") eval echo "\$FRA_LANGUAGE_SRV"$LANGUAGE;;
		"ita language srv") eval echo "\$ITA_LANGUAGE_SRV"$LANGUAGE;;
		"por language srv") eval echo "\$POR_LANGUAGE_SRV"$LANGUAGE;;
		"select option4 srv") eval echo "\$SELECT_OPTION4_SRV"$LANGUAGE;;
		"info user srv") eval echo "\$INFO_USER_SRV"$LANGUAGE;;
		"info copying srv") eval echo "\$INFO_COPYING_SRV"$LANGUAGE;;
		"select version srv") eval echo "\$SELECT_VERSION_SRV"$LANGUAGE;;
		"install demo srv") eval echo "\$INSTALL_DEMO_SRV"$LANGUAGE;;
		"install pago srv") eval echo "\$INSTALL_PAGO_SRV"$LANGUAGE;;
		"select option5 srv") eval echo "\$SELECT_OPTION5_SRV"$LANGUAGE;;
		"info code1 srv") eval echo "\$INFO_CODE1_SRV"$LANGUAGE;;
		"info code2 srv") eval echo "\$INFO_CODE2_SRV"$LANGUAGE;;
		"info code3 srv") eval echo "\$INFO_CODE3_SRV"$LANGUAGE;;
		"info code4 srv") eval echo "\$INFO_CODE4_SRV"$LANGUAGE;;
		"info scripts srv") eval echo "\$INFO_SCRIPTS_SRV"$LANGUAGE;;
		"info language srv") eval echo "\$INFO_LANGUAGE_SRV"$LANGUAGE;;
		"info propietario srv") eval echo "\$INFO_PROPIETARIO_SRV"$LANGUAGE;;
		"info proxycache srv") eval echo "\$INFO_PROXYCACHE_SRV"$LANGUAGE;;
		"info crontab1 srv") eval echo "\$INFO_CRONTAB1_SRV"$LANGUAGE;;
		"info crontab2 srv") eval echo "\$INFO_CRONTAB2_SRV"$LANGUAGE;;
		"info autostart1 srv") eval echo "\$INFO_AUTOSTART1_SRV"$LANGUAGE;;
		"info autostart2 srv") eval echo "\$INFO_AUTOSTART2_SRV"$LANGUAGE;;
		"info end1 srv") eval echo "\$INFO_END1_SRV"$LANGUAGE;;
		"info end2 srv") eval echo "\$INFO_END2_SRV"$LANGUAGE;;
		"info end3 srv") eval echo "\$INFO_END3_SRV"$LANGUAGE;;
		"info end4 srv") eval echo "\$INFO_END4_SRV"$LANGUAGE;;
		#optenet reporter
		"install reporter rpt") eval echo "\$INSTALL_REPORTER_RPT"$LANGUAGE;;
		"select option1 rpt") eval echo "\$SELECT_OPTION1_RPT"$LANGUAGE ["\$YES_ANSWER"$LANGUAGE];;
		"select language rpt") eval echo "\$SELECT_LANGUAGE_RPT"$LANGUAGE;;
		"esp language rpt") eval echo "\$ESP_LANGUAGE_RPT"$LANGUAGE;;
		"eng language rpt") eval echo "\$ENG_LANGUAGE_RPT"$LANGUAGE;;
		"fra language rpt") eval echo "\$FRA_LANGUAGE_SRV"$LANGUAGE;;
		"ita language rpt") eval echo "\$ITA_LANGUAGE_RPT"$LANGUAGE;;
		"por language rpt") eval echo "\$POR_LANGUAGE_RPT"$LANGUAGE;;
		"select option4 rpt") eval echo "\$SELECT_OPTION4_RPT"$LANGUAGE;;
		"info user rpt") eval echo "\$INFO_USER_RPT"$LANGUAGE;;
		"info copying rpt") eval echo "\$INFO_COPYING_RPT"$LANGUAGE;;
		"info scripts rpt") eval echo "\$INFO_SCRIPTS_RPT"$LANGUAGE;;
		"info language rpt") eval echo "\$INFO_LANGUAGE_RPT"$LANGUAGE;;
		"info filters rpt") eval echo "\$INFO_FILTERS_RPT"$LANGUAGE;;
		"info propietario rpt") eval echo "\$INFO_PROPIETARIO_RPT"$LANGUAGE;;
		"info autostart1 rpt") eval echo "\$INFO_AUTOSTART1_RPT"$LANGUAGE;;
		"info autostart2 rpt") eval echo "\$INFO_AUTOSTART2_RPT"$LANGUAGE;;
		"info end1 rpt") eval echo "\$INFO_END1_RPT"$LANGUAGE;;
		"info end2 rpt") eval echo "\$INFO_END2_RPT"$LANGUAGE;;
		"info end3 rpt") eval echo "\$INFO_END3_RPT"$LANGUAGE;;
		"info end4 rpt") eval echo "\$INFO_END4_RPT"$LANGUAGE;;
	esac
}

# root check
#if test $LOGNAME != "root"; then
if test "`id|cut -b 5`" != "0"; then
	print_text "error root ins"
	echo
	exit 1
fi

# unpack_file
# $1 Source File (without extension)
# $2 Destination Directory ($INSTALL_DIR)
# $3 Directory containing tar file ($TAR_PATH)
unpack_file()
{
	if test `uname -s` = SunOS;
	then
		cd $2; uncompress -c $3/$1.tar.Z | /usr/bin/tar xf -
	else
		tar xzf ./$1.tgz -C $2
	fi
}

# do_crontab
# $1 Destination Directory ($INSTALL_DIR) 
# $2 User ($USER)
do_crontab()
{
	if test `uname -s` = SunOS;
	then
		su - $2 -c "crontab $1/tools/logscron.conf"
	else
		crontab $1/tools/logscron.conf -u $2
	fi
}

# set_squid_group
# $1 Destination Directory ($INSTALL_DIR) 
set_squid_group()
{
	#setting squid group in linux systems
	if test `uname -s` != SunOS;
	then
		EXIST_NOGROUP=`grep ^nogroup /etc/group`
		if test -z $EXIST_NOGROUP; then
			sed "s:#cache_effective_group nobody:cache_effective_group nobody:g" \
				$1/squid/etc/squid.conf.tmpl \
				> $1/squid/etc/squid.conf.tmpl2
			mv  $1/squid/etc/squid.conf.tmpl2 \
				$1/squid/etc/squid.conf.tmpl	
		fi
	fi
}

# do_autostart
# $1 Destination Directory ($INSTALL_DIR) 
# $2 service name
do_autostart()
{
	if test `uname -s` = SunOS;
	then
		cp $1/tools/$2 /etc/init.d
		link /etc/init.d/$2 /etc/rc2.d/S99$2
		link /etc/init.d/$2 /etc/rc2.d/K99$2
	else
		if test -d /etc/init.d; then
		        cp $1/tools/$2 /etc/init.d
		        chkconfig --add $2
		        if test "$?" !=  "0"; then
		                #setting autostart
		                cp -s /etc/init.d/$2 /etc/rc0.d/K11$2
		                cp -s /etc/init.d/$2 /etc/rc1.d/K11$2
		                cp -s /etc/init.d/$2 /etc/rc2.d/K11$2
		                cp -s /etc/init.d/$2 /etc/rc3.d/S99$2
		                cp -s /etc/init.d/$2 /etc/rc4.d/S99$2
		                cp -s /etc/init.d/$2 /etc/rc5.d/S99$2
		                cp -s /etc/init.d/$2 /etc/rc6.d/K11$2
		        fi
		else
		if test -d /etc/rc.d/init.d; then
		        cp $1/tools/$2 /etc/rc.d/init.d
		        chkconfig --add $2
		        if test "$?" !=  "0"; then
		                #setting autostat 
		                cp -s /etc/rc.d/init.d/$2 /etc/rc0.d/K11$2
		                cp -s /etc/rc.d/init.d/$2 /etc/rc1.d/K11$2
		                cp -s /etc/rc.d/init.d/$2 /etc/rc2.d/K11$2
		                cp -s /etc/rc.d/init.d/$2 /etc/rc3.d/S99$2
		                cp -s /etc/rc.d/init.d/$2 /etc/rc4.d/S99$2
		                cp -s /etc/rc.d/init.d/$2 /etc/rc5.d/S99$2
		                cp -s /etc/rc.d/init.d/$2 /etc/rc6.d/K11$2
		        fi
		else
		        print_text "info autostart2 srv"
		fi
		fi
	fi
}

#START
echo
echo "OPTENET Setup"

tar xf $ALL_PACKET_NAME.tar

#Installation language
FIN="1"
echo
print_text "select language ins"
print_text "esp language ins"
print_text "eng language ins"
print_text "fra language ins"
print_text "ita language ins"
print_text "por language ins"
print_text "select option4 ins"
while test "$FIN" !=  "0";
        do
            read _INSTALL_LANG
	    if test "$_INSTALL_LANG" = ""; then
		_INSTALL_LANG=$LANGUAGE_TEXT 
	    fi
            case "$_INSTALL_LANG" in
                esp)
				LANGUAGE_TEXT="esp"
				LANGUAGE=_ESP
				FIN="0"
                ;;
                eng)
				LANGUAGE_TEXT="eng"
				LANGUAGE=_ENG
				FIN="0"
                ;;
                fra)	
				LANGUAGE_TEXT="fra"
				LANGUAGE=_FRA
				FIN="0"
                ;;
                ita)
				LANGUAGE_TEXT="ita"
				LANGUAGE=_ITA
				FIN="0"
                ;;
                por)
				LANGUAGE_TEXT="por"
				LANGUAGE=_POR
				FIN="0"
                ;;
                *)  
				print_text "select option4 ins"
                ;;
            esac
done

#OPTENET SERVER installation
FIN="1"
echo
print_text "install server srv"
print_text "select option1 srv"
eval _YES_TEXT="\$YES_ANSWER"$LANGUAGE
eval _NO_TEXT="\$NO_ANSWER"$LANGUAGE
while test "$FIN" !=  "0";
        do
            read _ANSWER_YES_NO
            if test "$_ANSWER_YES_NO" = ""; then
                _ANSWER_YES_NO=$_YES_TEXT
            fi
            case "$_ANSWER_YES_NO" in
                $_YES_TEXT)
			FIN="0"			
			;;
                $_NO_TEXT)
			FIN="0"
			;;
                *)
			print_text "select option1 srv"
			;;
            esac
done

if test "$_ANSWER_YES_NO" = $_YES_TEXT; then
FIN="1"
# choosing filter modality installation
echo
print_text "select mode srv"
print_text "install rpc srv"
print_text "install icap srv"
print_text "install bm srv"
print_text "install pix srv"
print_text "install ufp srv"
print_text "install csp srv"
print_text "install ipl srv"
print_text "select option2 srv"
while test "$FIN" !=  "0";
        do
            read _ANSWER
			if test "$_ANSWER" = ""; then
				_ANSWER="RPC"
			fi
            case "$_ANSWER" in
                RPC)
				FIN="0"
                ;;
                ICAP)
				FIN="0"
                ;;
		BM)
				FIN="0"
                ;;
		UFP)
				FIN="0"
                ;;
		PIX)
				FIN="0"
                ;;
		CSP)
				FIN="0"
                ;;
		IPL)
				FIN="0"
                ;;
                *)  
				print_text "select option3 srv"
                ;;
            esac
done

# choosing default administration language
FIN="1"
echo
print_text "select language srv"
print_text "esp language srv"
print_text "eng language srv"
print_text "fra language srv"
print_text "ita language srv"
print_text "por language srv"
print_text "select option4 srv"
while test "$FIN" !=  "0";
        do
            read _ANSWER_LANG
	    if test "$_ANSWER_LANG" = ""; then
		_ANSWER_LANG=$LANGUAGE_TEXT
	    fi
            case "$_ANSWER_LANG" in
                esp)
				FIN="0"
                ;;
                fra)
				FIN="0"
                ;;
                eng)
				FIN="0"
                ;;
                ita)
				FIN="0"
                ;;
                por)
				FIN="0"
                ;;
                *)  
				print_text "select option4 srv"
                ;;
            esac
done

# creating new user and coping software
echo
print_text "info user srv"
useradd -m -d $INSTALL_DIR $USER

print_text "info copying srv"
unpack_file $SERVER_PACKET_NAME $INSTALL_DIR $TAR_PATH

# License type
FIN="1"
echo
print_text "select version srv"
print_text "install demo srv"
print_text "install pago srv"
print_text "select option5 srv"
while test "$FIN" !=  "0";
        do
            read _ANSWER_LICENSE_TYPE
            if test "$_ANSWER_LICENSE_TYPE" = ""; then
		_ANSWER_LICENSE_TYPE="dem"
	    fi
            case "$_ANSWER_LICENSE_TYPE" in
                dem)
				FIN="0"
                ;;
                pay)
				FIN="0"
                ;;
                *)  
				print_text "select option5 srv"
                ;;
            esac
done

#Choosing installation binary
if test -f "/etc/redhat-release"; then
	if test "`cat /etc/redhat-release|cut -b 1-19`" = "Fedora Core release" -o "`cat /etc/redhat-release|cut -b 1-16`" = "CentOS release 4"; then
		rm -f $INSTALL_DIR$SERVICE
		mv $INSTALL_DIR$SERVICE_RHE3 $INSTALL_DIR$SERVICE
		rm -f $INSTALL_DIR$LISTCLUSTERS
		mv $INSTALL_DIR$LISTCLUSTERS_RHE3 $INSTALL_DIR$LISTCLUSTERS
	else if test "`cat /etc/redhat-release|cut -b 1-37`" = "Red Hat Enterprise Linux AS release 4" -o "`cat /etc/redhat-release|cut -b 1-37`" = "Red Hat Enterprise Linux ES release 4"; then
		rm -f $INSTALL_DIR$SERVICE
		mv $INSTALL_DIR$SERVICE_RHE3 $INSTALL_DIR$SERVICE
		rm -f $INSTALL_DIR$LISTCLUSTERS
		mv $INSTALL_DIR$LISTCLUSTERS_RHE3 $INSTALL_DIR$LISTCLUSTERS
	else if test "`cat /etc/redhat-release|cut -b 1-37`" = "Red Hat Enterprise Linux AS release 3"; then
		rm -f $INSTALL_DIR$SERVICE
		mv $INSTALL_DIR$SERVICE_RHE3 $INSTALL_DIR$SERVICE
		rm -f $INSTALL_DIR$LISTCLUSTERS
		mv $INSTALL_DIR$LISTCLUSTERS_RHE3 $INSTALL_DIR$LISTCLUSTERS
	else 
		rm -f $INSTALL_DIR$SERVICE_RHE3
		rm -f $INSTALL_DIR$LISTCLUSTERS_RHE3
	fi
	fi
	fi
	rm -f $INSTALL_DIR$SERVICE_SUSE93
	rm -f $INSTALL_DIR$LISTCLUSTERS_SUSE93
else
	if test -f "/etc/SuSE-release"; then
		rm -f $INSTALL_DIR$SERVICE_RHE3
		rm -f $INSTALL_DIR$LISTCLUSTERS_RHE3
		if test "`head -1 /etc/SuSE-release|cut -b 1-14`" = "SuSE Linux 9.3" -o "`head -1 /etc/SuSE-release|cut -b 1-14`" = "SUSE LINUX 10."; then
			rm -f $INSTALL_DIR$SERVICE
			mv $INSTALL_DIR$SERVICE_SUSE93 $INSTALL_DIR$SERVICE
			rm -f $INSTALL_DIR$LISTCLUSTERS
			mv $INSTALL_DIR$LISTCLUSTERS_SUSE93 $INSTALL_DIR$LISTCLUSTERS
		else 
			rm -f $INSTALL_DIR$SERVICE_SUSE93
			rm -f $INSTALL_DIR$LISTCLUSTERS_SUSE93
		fi
	else
		rm -f $INSTALL_DIR$SERVICE_RHE3
		rm -f $INSTALL_DIR$LISTCLUSTERS_RHE3
		rm -f $INSTALL_DIR$SERVICE_SUSE93
		rm -f $INSTALL_DIR$LISTCLUSTERS_SUSE93
	fi
fi

# getting licence code
FIN="1"
failcount=0
if test "$_ANSWER_LICENSE_TYPE" = "pay"; then
	echo
	print_text "info code1 srv"
	print_text "info code2 srv"
	while test "$FIN" !=  "0" -a $failcount -lt 3;
        do
		read _ANSWER_LICENSE_CODE
		# checking licence code
		$INSTALL_DIR$SERVICE $INSTALL_DIR -license_code $_ANSWER_LICENSE_CODE 2>/dev/null
	        if test "$?" !=  "0"; then
			print_text "info code3 srv"	
			failcount=`expr $failcount + 1`
		else
			FIN="0"
		fi
	done
	if test $failcount -gt 2 ; then
		print_text "info code4 srv"
	fi
fi

if test "$_ANSWER" = "RPC"; then
	set_squid_group $INSTALL_DIR
	sed "s:INSTALL_DIR:$INSTALL_DIR:g" $INSTALL_DIR/squid/etc/squid.conf.tmpl\
		> $INSTALL_DIR/squid/etc/squid.conf.tmpl2
	sed "s:USER:$USER:g" $INSTALL_DIR/squid/etc/squid.conf.tmpl2\
		> $INSTALL_DIR/squid/etc/squid.conf
	rm -f $INSTALL_DIR/squid/etc/squid.conf.tmp*
	sed "s:INSTALL_DIR:$INSTALL_DIR:g" $INSTALL_DIR/squid/RunSQUID.tmpl \
		> $INSTALL_DIR/squid/RunSQUID
	chmod +x $INSTALL_DIR/squid/RunSQUID
	rm -f $INSTALL_DIR/squid/RunSQUID.tmpl
	rm -f $INSTALL_DIR/filterinit_icap.tmpl
	rm -f $INSTALL_DIR/RunOPTENET_icap.tmpl
	rm -f $INSTALL_DIR/RunOPTENET_bm.tmpl
	rm -f $INSTALL_DIR/RunOPTENET_pix.tmpl
	rm -f $INSTALL_DIR/RunOPTENET_ufp.tmpl
	rm -f $INSTALL_DIR/RunOPTENET_csp.tmpl
	rm -f $INSTALL_DIR/etc/n2h2.acl
else
	if test "$_ANSWER" = "BM"; then
		mv $INSTALL_DIR/filterinit_icap.tmpl $INSTALL_DIR/filterinit.tmpl
		mv $INSTALL_DIR/RunOPTENET_bm.tmpl $INSTALL_DIR/RunOPTENET.tmpl
		rm -f $INSTALL_DIR/RunOPTENET_icap.tmpl
		rm -f $INSTALL_DIR/RunOPTENET_pix.tmpl
		rm -f $INSTALL_DIR/RunOPTENET_ufp.tmpl
		rm -f $INSTALL_DIR/RunOPTENET_csp.tmpl
	else if test "$_ANSWER" = "PIX"; then
		mv $INSTALL_DIR/filterinit_icap.tmpl $INSTALL_DIR/filterinit.tmpl
		mv $INSTALL_DIR/RunOPTENET_pix.tmpl $INSTALL_DIR/RunOPTENET.tmpl
		rm -f $INSTALL_DIR/RunOPTENET_icap.tmpl
		rm -f $INSTALL_DIR/RunOPTENET_bm.tmpl
		rm -f $INSTALL_DIR/RunOPTENET_ufp.tmpl
		rm -f $INSTALL_DIR/RunOPTENET_csp.tmpl
		rm -f $INSTALL_DIR/etc/n2h2.acl
	else if test "$_ANSWER" = "UFP"; then
		mv $INSTALL_DIR/filterinit_icap.tmpl $INSTALL_DIR/filterinit.tmpl
		mv $INSTALL_DIR/RunOPTENET_ufp.tmpl $INSTALL_DIR/RunOPTENET.tmpl
		rm -f $INSTALL_DIR/RunOPTENET_icap.tmpl
		rm -f $INSTALL_DIR/RunOPTENET_bm.tmpl
		rm -f $INSTALL_DIR/RunOPTENET_pix.tmpl
		rm -f $INSTALL_DIR/RunOPTENET_csp.tmpl
		rm -f $INSTALL_DIR/etc/n2h2.acl
	else if test "$_ANSWER" = "CSP"; then
		mv $INSTALL_DIR/filterinit_icap.tmpl $INSTALL_DIR/filterinit.tmpl
		mv $INSTALL_DIR/RunOPTENET_csp.tmpl $INSTALL_DIR/RunOPTENET.tmpl
		rm -f $INSTALL_DIR/RunOPTENET_icap.tmpl
		rm -f $INSTALL_DIR/RunOPTENET_bm.tmpl
		rm -f $INSTALL_DIR/RunOPTENET_pix.tmpl
		rm -f $INSTALL_DIR/RunOPTENET_ufp.tmpl
		rm -f $INSTALL_DIR/etc/n2h2.acl
	else if test "$_ANSWER" = "IPL"; then
		mv $INSTALL_DIR/filterinit_icap.tmpl $INSTALL_DIR/filterinit.tmpl
		rm -f $INSTALL_DIR/RunOPTENET_ufp.tmpl
		rm -f $INSTALL_DIR/RunOPTENET_icap.tmpl
		rm -f $INSTALL_DIR/RunOPTENET_bm.tmpl
		rm -f $INSTALL_DIR/RunOPTENET_pix.tmpl
		rm -f $INSTALL_DIR/etc/n2h2.acl
	else
		mv $INSTALL_DIR/filterinit_icap.tmpl $INSTALL_DIR/filterinit.tmpl
		mv $INSTALL_DIR/RunOPTENET_icap.tmpl $INSTALL_DIR/RunOPTENET.tmpl
		rm -f $INSTALL_DIR/RunOPTENET_bm.tmpl
		rm -f $INSTALL_DIR/RunOPTENET_pix.tmpl
		rm -f $INSTALL_DIR/RunOPTENET_ufp.tmpl
		rm -f $INSTALL_DIR/RunOPTENET_csp.tmpl
		rm -f $INSTALL_DIR/etc/n2h2.acl
	fi
	fi
	fi
	fi
	fi
fi

# modifying installation directory in all scripts
print_text "info scripts srv"

sed "s:INSTALL_DIR:$INSTALL_DIR:g" $INSTALL_DIR/RunOPTENET.tmpl \
	> $INSTALL_DIR/RunOPTENET
chmod +x $INSTALL_DIR/RunOPTENET
rm -f $INSTALL_DIR/RunOPTENET.tmpl

sed "s:INSTALL_DIR:$INSTALL_DIR:g" $INSTALL_DIR/filterinit.tmpl \
	> $INSTALL_DIR/filterinit
chmod +x $INSTALL_DIR/filterinit
rm -f $INSTALL_DIR/filterinit.tmpl

sed "s:INSTALL_DIR:$INSTALL_DIR:g" $INSTALL_DIR/stunnelinit.tmpl \
	> $INSTALL_DIR/stunnelinit
chmod +x $INSTALL_DIR/stunnelinit
rm -f $INSTALL_DIR/stunnelinit.tmpl

sed "s:USER:$USER:g" $INSTALL_DIR/tools/optenet.tmpl \
	> $INSTALL_DIR/tools/$AUTOSTART_SERVER_NAME
chmod +x $INSTALL_DIR/tools/$AUTOSTART_SERVER_NAME
rm -f $INSTALL_DIR/tools/optenet.tmpl

sed "s:INSTALL_DIR:$INSTALL_DIR:g" $INSTALL_DIR/etc/config.conf.tmpl \
	> $INSTALL_DIR/etc/config.conf
rm -f $INSTALL_DIR/etc/config.conf.tmpl

# setting default language
print_text "info language srv"

sed "s:\"esp\":\"$_ANSWER_LANG\":g" $INSTALL_DIR/etc/config.conf \
	> $INSTALL_DIR/etc/config.conf.lang
mv $INSTALL_DIR/etc/config.conf.lang $INSTALL_DIR/etc/config.conf

sed "s:LANG=esp:LANG=$_ANSWER_LANG:g" $INSTALL_DIR/manager/index.htm \
	> $INSTALL_DIR/manager/index.htm.lang
mv $INSTALL_DIR/manager/index.htm.lang $INSTALL_DIR/manager/index.htm

# setting USER as software owner.
print_text "info propietario srv"
chown -R $USER $INSTALL_DIR

if test "$_ANSWER" = "RPC"; then
	# Creating squid cache
	print_text "info proxycache srv"
	su - $USER -c "$INSTALL_DIR/squid/sbin/squid -z -f $INSTALL_DIR/squid/etc/squid.conf" 2>/dev/null
	# programming squid logs rotation task
	echo
	print_text "info crontab1 srv"
	print_text "info crontab2 srv"
	sed "s:INSTALL_DIR:$INSTALL_DIR:g" $INSTALL_DIR/tools/logscron.tmpl > $INSTALL_DIR/tools/logscron.conf
	rm -f $INSTALL_DIR/tools/logscron.tmpl
	do_crontab $INSTALL_DIR $USER
else
	rm -rf $INSTALL_DIR/squid
fi

# setting autostart in boot process
echo
print_text "info autostart1 srv"
do_autostart $INSTALL_DIR $AUTOSTART_SERVER_NAME

echo
print_text "info end1 srv"
print_text "info end2 srv"
print_text "info end3 srv"
print_text "info end4 srv"
fi

#OPTENET_REPORTER installation
FIN="1"
echo
echo
print_text "install reporter rpt"
print_text "select option1 rpt"
eval _YES_TEXT="\$YES_ANSWER"$LANGUAGE
eval _NO_TEXT="\$NO_ANSWER"$LANGUAGE
while test "$FIN" !=  "0";
        do
	    read _ANSWER_YES_NO
	    if test "$_ANSWER_YES_NO" = ""; then
	        _ANSWER_YES_NO=$_YES_TEXT
            fi
            case "$_ANSWER_YES_NO" in
                $_YES_TEXT)
			FIN="0"
			;;
                $_NO_TEXT)
			exit
			;;
                *)
			print_text "select option1 rpt"
			;;
            esac
done

if test "$_ANSWER_YES_NO" = $_YES_TEXT; then
# choosing default administration language
FIN="1"
echo
print_text "select language rpt"
print_text "esp language rpt"
print_text "eng language rpt"
print_text "fra language rpt"
print_text "ita language rpt"
print_text "por language rpt"
print_text "select option4 rpt"
while test "$FIN" !=  "0";
        do
            read _ANSWER_LANG
            if test "$_ANSWER_LANG" = ""; then
	            _ANSWER_LANG=$LANGUAGE_TEXT
            fi
            case "$_ANSWER_LANG" in
                esp)
                FIN="0"
                ;;
                fra)
                FIN="0"
                ;;
                eng)
                FIN="0"
                ;;
                ita)
                FIN="0"
                ;;
                por)
                FIN="0"
                ;;
                *)
                print_text "select option4 rpt"
                ;;
            esac
done

# creating new user and copying software
echo
print_text "info user rpt"
useradd -m -d $INSTALL_DIR_REP $USER_REP

print_text "info copying rpt"
unpack_file $REPORTER_PACKET_NAME $INSTALL_DIR_REP $TAR_PATH

#setting installation directory in all scripts
print_text "info scripts rpt"

sed "s:INSTALL_DIR:$INSTALL_DIR_REP:g" $INSTALL_DIR_REP/RunReporter.tmpl \
	> $INSTALL_DIR_REP/RunReporter.aux
sed "s:LANG:$_ANSWER_LANG:g" $INSTALL_DIR_REP/RunReporter.aux \
	> $INSTALL_DIR_REP/RunReporter
chmod +x $INSTALL_DIR_REP/RunReporter
rm -f $INSTALL_DIR_REP/RunReporter.tmpl
rm -f $INSTALL_DIR_REP/RunReporter.aux

sed "s:INSTALL_DIR:$INSTALL_DIR_REP:g" $INSTALL_DIR_REP/reporterinit.tmpl \
	> $INSTALL_DIR_REP/reporterinit
chmod +x $INSTALL_DIR_REP/reporterinit
rm -f $INSTALL_DIR_REP/reporterinit.tmpl

sed "s:USER:$USER_REP:g" $INSTALL_DIR_REP/tools/reporter.tmpl \
	> $INSTALL_DIR_REP/tools/$AUTOSTART_REPORTER_NAME
chmod +x $INSTALL_DIR_REP/tools/$AUTOSTART_REPORTER_NAME
rm -f $INSTALL_DIR_REP/tools/reporter.tmpl

sed "s:INSTALL_DIR:$INSTALL_DIR_REP:g" $INSTALL_DIR_REP/etc/updates.conf.tmpl \
	> $INSTALL_DIR_REP/etc/updates.conf
rm -f $INSTALL_DIR_REP/etc/updates.conf.tmpl

# choosing default administration language
print_text "info language rpt"
sed "s:LANG=esp:LANG=$_ANSWER_LANG:g" $INSTALL_DIR_REP/manager/indexLw.htm \
        > $INSTALL_DIR_REP/manager/index.htm.lang
mv $INSTALL_DIR_REP/manager/index.htm.lang $INSTALL_DIR_REP/manager/indexLw.htm

# setting default OPTENET filter controlled by the OPTENET reporter
print_text "info filters rpt"
grep $USER /etc/passwd>/dev/null
if test $? != "0"; then
	rm -f $INSTALL_DIR_REP/etc/filter.conf.local.tmpl
	mv $INSTALL_DIR_REP/etc/filter.conf.blanck.tmpl $INSTALL_DIR_REP/etc/filter.conf
else
	rm -f $INSTALL_DIR_REP/etc/filter.conf.blanck.tmpl
	mv $INSTALL_DIR_REP/etc/filter.conf.local.tmpl $INSTALL_DIR_REP/etc/filter.conf
fi	

#setting $USER_REP as software owner
print_text "info propietario rpt"
chown -R $USER_REP $INSTALL_DIR_REP

# setting autostart in boot process
print_text "info autostart1 rpt"
do_autostart $INSTALL_DIR_REP $AUTOSTART_REPORTER_NAME

echo
print_text "info end1 rpt"
print_text "info end2 rpt"
print_text "info end3 rpt"
print_text "info end4 rpt"

fi

echo
